==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Szélesség:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Térköz:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Tartam</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Egyes értesítések megjelenési ideje.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Alapértelmezett tartam:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> mp</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Értesítő démon nem fut.
A vésztartalék használatos.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Egy másik, a (%1) értesítésfigyelő már fut.
Ezek a beállítások arra már hatástalanok!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Értesítés bemutató</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Értesítési teszt.
 Az értesítéseket az LXQt így fogja megjeleníteni.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Asztali értesítések</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Haladó beállítások</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Szélesség:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Térköz:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Tartam</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Egyes értesítések megjelenési ideje.</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Alapértelmezett tartam:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> mp</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Értesítő démon nem fut.
A vésztartalék használatos.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Egy másik, a (%1) értesítésfigyelő már fut.
Ezek a beállítások arra már hatástalanok!</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Értesítés bemutató</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Értesítési teszt.
 Az értesítéseket az LXQt így fogja megjeleníteni.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Asztali értesítések</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Alapbeállítások</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Haladó beállítások</translation>
    </message>
</context>
</TS>
